@@ -1,6 +1,6 @@
 /* util.c
  *
- * Copyright (c) 1992-2003 by Mike Gleason.
+ * Copyright (c) 1992-2004 by Mike Gleason.
  * All rights reserved.
  * 
  */
@@ -383,7 +383,7 @@ InitOurDirectory(void)
 			cp = strrchr(gOurDirectoryPath, '"');
 			if ((cp != NULL) && (cp[1] == '\0'))
 				*cp = '\0';
-		} else if ((cp = getenv("HOME")) != NULL) {
+		} else if ((cp = getenv("USERPROFILE")) != NULL) {
 			if (*cp == '"')
 				cp++;
 			(void) STRNCPY(gOurDirectoryPath, cp);
